@@ -1,6 +1,7 @@
-#!/usr/bin/python
+#!/usr/bin/env python
 # -*- coding: utf-8 -*-
 #
+# Copyright (c) 2014 Daniel Standage <daniel.standage@gmail.com>
 # Copyright (c) 2010 Sascha Steinbiss <steinbiss@zbh.uni-hamburg.de>
 # Copyright (c) 2010 Center for Bioinformatics, University of Hamburg
 #
@@ -18,11 +19,17 @@
 #
 
 from gt.dlload import gtlib
+from ctypes import CFUNCTYPE, c_void_p, c_char_p, addressof
+
+funcdef = CFUNCTYPE(None, c_void_p, c_char_p, c_char_p)
+defhand = funcdef.in_dll(gtlib, "gt_warning_default_handler")
+gtlib.gt_warning_disable.restype = None
+gtlib.gt_warning_disable.argtypes = []
+gtlib.gt_warning_set_handler.restype = None
+gtlib.gt_warning_set_handler.argtypes = [funcdef, c_void_p]
 
 def warning_disable():
     gtlib.gt_warning_disable()
 
 def warning_enable_default():
-    from ctypes import CFUNCTYPE, c_void_p, c_char_p, addressof
-    defhand = CFUNCTYPE(None, c_void_p, c_char_p, c_char_p).in_dll(gtlib, "gt_warning_default_handler")
     gtlib.gt_warning_set_handler(addressof(defhand), None)
