@@ -34,7 +34,11 @@ def parseargs(argv)
   options.jobs = 4
   options.fileargs = nil
   options.threads = true
+  options.sketch = false
   opts = OptionParser.new
+  opts.on("--sketch","compile with annotation sketch") do |x|
+    options.sketch = true
+  end
   opts.on("--m64","compile 64 bit binary") do |x|
     options.m64 = true
   end
@@ -64,7 +68,7 @@ def parseargs(argv)
 end
 
 def makecompilerflags(fp,options)
-  fp.print "all:\n\t\${MAKE} -j #{options.jobs} with-sqlite=no cairo=no"
+  fp.print "all:\n\t\${MAKE} -j #{options.jobs} wrapmemcpy=yes with-sqlite=no"
   # fp.print " CFLAGS+=-fstrict-aliasing"
   if options.speed
     fp.print " assert=no amalgamation=yes"
@@ -81,7 +85,12 @@ def makecompilerflags(fp,options)
   if options.threads
     fp.print " threads=yes"
   end
-  fp.print " CC='ccache " + ENV["CC"] + "'"
+  if ENV.has_key?("SKETCH") and ENV["SKETCH"] == "yes"
+    fp.print " cairo=yes"
+  else
+    fp.print " cairo=no"
+  end
+  fp.print " CPPFLAGS='-fno-stack-protector -U_FORTIFY_SOURCE -D_GNU_SOURCE' CC='ccache " + ENV["CC"] + "'"
   if not options.fileargs.nil?
     filenames=options.fileargs.join(" ")
     fp.puts " #{filenames}"
