@@ -40,8 +40,9 @@
    the bins can be sorted by independet threads which have independent
    workspace.
 
-   5) The implementation allows one to sort an GtUword -array and an array
-   over type <GtUlongPair>, where the component <a> is the soring key.
+   5) The implementation allows one to sort a <GtUword>-array and a
+      <GtUlongPair>-array. In the latter case the
+      the component <a> of type <GtUlongPair> is the soring key.
 */
 
 #include <stdio.h>
@@ -53,11 +54,9 @@
 #include "core/assert_api.h"
 #include "core/divmodmul.h"
 #include "core/minmax.h"
-#include "core/radix_sort.h"
-#include "core/range_api.h"
-#include "core/stack-inlined.h"
 #include "core/types_api.h"
-#include "core/unused_api.h"
+#include "core/stack-inlined.h"
+#include "core/radix_sort.h"
 #ifdef GT_THREADS_ENABLED
 #include "core/thread_api.h"
 #endif
@@ -243,7 +242,7 @@ static void gt_evenly_divide_lentab(GtUword *endindexes,
 typedef union
 {
   GtUword *ulongptr;
-  GtUlongPair *ulongpairptr;
+  GtUwordPair *ulongpairptr;
 } GtRadixvalues;
 
 typedef struct
@@ -468,7 +467,7 @@ void gt_radixsort_delete(GtRadixsortinfo *radixsortinfo)
 
 static size_t gt_radixsort_elemsize(bool pair)
 {
-  return pair ? sizeof (GtUlongPair) : sizeof (GtUword);
+  return pair ? sizeof (GtUwordPair) : sizeof (GtUword);
 }
 
 GtUword gt_radixsort_max_num_of_entries_ulong(size_t memlimit)
@@ -582,7 +581,7 @@ void gt_radixsort_inplace_ulong(GtUword *source, GtUword len)
   gt_radixsort_delete(radixsortinfo);
 }
 
-void gt_radixsort_inplace_GtUlongPair(GtUlongPair *source, GtUword len)
+void gt_radixsort_inplace_GtUwordPair(GtUwordPair *source, GtUword len)
 {
   GtRadixvalues radixvalues;
   GtRadixsortinfo *radixsortinfo;
@@ -604,7 +603,7 @@ GtUword *gt_radixsort_space_ulong(GtRadixsortinfo *radixsortinfo)
   return radixsortinfo->sortspace.ulongptr;
 }
 
-GtUlongPair *gt_radixsort_space_ulongpair(GtRadixsortinfo *radixsortinfo)
+GtUwordPair *gt_radixsort_space_ulongpair(GtRadixsortinfo *radixsortinfo)
 {
   gt_assert(radixsortinfo->pairs);
   return radixsortinfo->sortspace.ulongpairptr;
