@@ -15,13 +15,11 @@
   OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */
 
-#include <math.h>
 #include <errno.h>
-#ifndef S_SPLINT_S
 #include <fcntl.h>
+#include <math.h>
 #include <sys/stat.h>
 #include <unistd.h>
-#endif
 
 #include "core/arraydef.h"
 #include "core/assert_api.h"
@@ -161,11 +159,11 @@ static int encdesc_analyze_descs(GtEncdesc *encdesc,
 
   encdesc->num_of_fields = 0;
   encdesc->num_of_fields_is_cons = true;
-  GT_INITARRAY(&encdesc->num_of_fields_tab, GtUlong);
+  GT_INITARRAY(&encdesc->num_of_fields_tab, GtUword);
 
   /* find description with maximum number of fields */
-  /* TODO check constant number of fields here */
-  /* TODO count totalnumofchars here */
+  /* TODO DW check constant number of fields here */
+  /* TODO DW count totalnumofchars here */
   gt_error_check(err);
   status = gt_cstr_iterator_next(cstr_iterator, &descbuffer, err);
   while (status != 0) {
@@ -245,7 +243,7 @@ static int encdesc_analyze_descs(GtEncdesc *encdesc,
         cur_field->max_zero = 0;
         cur_field->num_values_size = 0;
         cur_field->delta_values_size = 0;
-        if (gt_parse_long(&out, cur_field->data) == 0) {
+        if (gt_parse_word(&out, cur_field->data) == 0) {
           cur_field->is_numeric = true;
           cur_field->max_value = out;
           cur_field->min_value = out;
@@ -331,7 +329,7 @@ static int encdesc_analyze_descs(GtEncdesc *encdesc,
           }
 
           if (cur_field->is_numeric) {
-            if (gt_parse_long(&out, (mutable_desc + start_pos)) != 0)
+            if (gt_parse_word(&out, (mutable_desc + start_pos)) != 0)
               cur_field->is_numeric = false;
             else {
 
@@ -421,10 +419,10 @@ static int encdesc_analyze_descs(GtEncdesc *encdesc,
           (desc_char_idx != desclength))
         encdesc->num_of_fields_is_cons = false;
 
-      GT_STOREINARRAY(&encdesc->num_of_fields_tab, GtUlong, 128 ,cur_field_num);
+      GT_STOREINARRAY(&encdesc->num_of_fields_tab, GtUword, 128 ,cur_field_num);
 
-      /* TODO this heuristic is bad, if the 2nd field is missing, all following
-         fields are missing too! */
+      /* TODO DW this heuristic is bad, if the 2nd field is missing, all
+         following fields are missing too! */
       /* change this so a field can be absent in a single description */
       /* absent fields are non constant */
       for (;cur_field_num < encdesc->num_of_fields;cur_field_num++) {
@@ -441,7 +439,7 @@ static int encdesc_analyze_descs(GtEncdesc *encdesc,
 
     encdesc->num_of_descs = cur_desc;
     if (encdesc->num_of_fields_is_cons) {
-      GT_FREEARRAY(&encdesc->num_of_fields_tab, GtUlong);
+      GT_FREEARRAY(&encdesc->num_of_fields_tab, GtUword);
     }
 
     for (cur_field_num = 0;
@@ -457,8 +455,8 @@ static int encdesc_analyze_descs(GtEncdesc *encdesc,
         }
       }
       else {
-        /* TODO range can be large, but the size of the dist is more important
-           for huffman coding */
+        /* TODO DW range can be large, but the size of the dist is more
+           important for huffman coding */
         GtWord value_range, delta_range;
         value_range = labs(cur_field->max_value - cur_field->min_value);
         delta_range = labs(cur_field->max_delta - cur_field->min_delta);
@@ -681,7 +679,7 @@ static inline void encdesc_prepare_num_of_fields(GtEncdesc *encdesc,
 {
   GtBitsequence code;
   code =
-    (GtBitsequence) encdesc->num_of_fields_tab.spaceGtUlong[info->cur_desc];
+    (GtBitsequence) encdesc->num_of_fields_tab.spaceGtUword[info->cur_desc];
   prepare_generic(info,
                   (unsigned) encdesc->bits_per_field,
                   code);
@@ -692,7 +690,7 @@ static void parse_number_out_of_current_field(EncdescWriteInfo *info,
                                               GtWord *retval)
 {
   char *cur_field_num = info->descbuffer + info->cur_field_start_pos;
-  GT_UNUSED int had_err = gt_parse_long(retval, cur_field_num);
+  GT_UNUSED int had_err = gt_parse_word(retval, cur_field_num);
   gt_assert(!had_err);
 }
 
@@ -1392,7 +1390,7 @@ static int encdesc_next_desc(GtEncdesc *encdesc, GtStr *desc, GtError *err)
             gt_str_append_char(desc, '0');
         }
         if (desc != NULL) {
-          gt_str_append_ulong(desc, (GtUword) tmp);
+          gt_str_append_uword(desc, (GtUword) tmp);
           gt_str_append_char(desc, cur_field->sep);
         }
         continue;
@@ -1572,7 +1570,7 @@ void gt_encdesc_delete(GtEncdesc *encdesc)
 {
   if (!encdesc) return;
   gt_bitinstream_delete(encdesc->bitinstream);
-  GT_FREEARRAY(&encdesc->num_of_fields_tab, GtUlong);
+  GT_FREEARRAY(&encdesc->num_of_fields_tab, GtUword);
   encdesc_delete_desc_fields(encdesc->fields, encdesc->num_of_fields);
   gt_sampling_delete(encdesc->sampling);
   gt_free(encdesc);
