@@ -1,6 +1,6 @@
 /*
-  Copyright (c) 2006-2013 Gordon Gremme <gordon@gremme.org>
-  Copyright (c) 2006-2008 Center for Bioinformatics, University of Hamburg
+  Copyright (c) 2006-2013, 2015 Gordon Gremme <gordon@gremme.org>
+  Copyright (c) 2006-2008       Center for Bioinformatics, University of Hamburg
 
   Permission to use, copy, modify, and distribute this software for any
   purpose with or without fee is hereby granted, provided that the above
@@ -20,6 +20,7 @@
 #include <string.h>
 #include "core/assert_api.h"
 #include "core/fasta.h"
+#include "core/file.h"
 #include "core/hashmap.h"
 #include "core/ma.h"
 #include "core/unused_api.h"
@@ -37,12 +38,14 @@ struct GtGFF3Visitor {
   const GtNodeVisitor parent_instance;
   bool version_string_shown,
        retain_ids,
-       fasta_directive_shown;
+       fasta_directive_shown,
+       allow_nonunique_ids;
   GtStringDistri *id_counter;
   GtHashmap *feature_node_to_id_array,
             *feature_node_to_unique_id_str;
   GtUword fasta_width;
   GtFile *outfp;
+  GtStr *outstr;
   GtCstrTable *used_ids;
 };
 
@@ -54,6 +57,7 @@ typedef struct {
 typedef struct {
   bool *attribute_shown;
   GtFile *outfp;
+  GtStr *outstr;
 } ShowAttributeInfo;
 
 #define gff3_visitor_cast(GV)\
@@ -64,8 +68,15 @@ static void gff3_version_string(GtNodeVisitor *nv)
   GtGFF3Visitor *gff3_visitor = gff3_visitor_cast(nv);
   gt_assert(gff3_visitor);
   if (!gff3_visitor->version_string_shown) {
-    gt_file_xprintf(gff3_visitor->outfp, "%s   %u\n", GT_GFF_VERSION_PREFIX,
-                    GT_GFF_VERSION);
+    if (!gff3_visitor->outstr) {
+      gt_file_xprintf(gff3_visitor->outfp, "%s   %u\n", GT_GFF_VERSION_PREFIX,
+                      GT_GFF_VERSION);
+    } else {
+      gt_str_append_cstr(gff3_visitor->outstr, GT_GFF_VERSION_PREFIX);
+      gt_str_append_cstr(gff3_visitor->outstr, "   ");
+      gt_str_append_uint(gff3_visitor->outstr, GT_GFF_VERSION);
+      gt_str_append_char(gff3_visitor->outstr, '\n');
+    }
     gff3_visitor->version_string_shown = true;
   }
 }
@@ -78,6 +89,8 @@ static void gff3_visitor_free(GtNodeVisitor *nv)
   gt_hashmap_delete(gff3_visitor->feature_node_to_id_array);
   gt_hashmap_delete(gff3_visitor->feature_node_to_unique_id_str);
   gt_cstr_table_delete(gff3_visitor->used_ids);
+  gt_str_delete(gff3_visitor->outstr);
+  gt_file_delete(gff3_visitor->outfp);
 }
 
 static int gff3_visitor_comment_node(GtNodeVisitor *nv, GtCommentNode *cn,
@@ -88,8 +101,14 @@ static int gff3_visitor_comment_node(GtNodeVisitor *nv, GtCommentNode *cn,
   gff3_visitor = gff3_visitor_cast(nv);
   gt_assert(nv && cn);
   gff3_version_string(nv);
-  gt_file_xprintf(gff3_visitor->outfp, "#%s\n",
-                  gt_comment_node_get_comment(cn));
+  if (!gff3_visitor->outstr) {
+    gt_file_xprintf(gff3_visitor->outfp, "#%s\n",
+                    gt_comment_node_get_comment(cn));
+  } else  {
+    gt_str_append_char(gff3_visitor->outstr, '#');
+    gt_str_append_cstr(gff3_visitor->outstr, gt_comment_node_get_comment(cn));
+    gt_str_append_char(gff3_visitor->outstr, '\n');
+  }
   return 0;
 }
 
@@ -114,11 +133,20 @@ static void show_attribute(const char *attr_name, const char *attr_value,
   ShowAttributeInfo *info = (ShowAttributeInfo*) data;
   gt_assert(attr_name && attr_value && info);
   if (strcmp(attr_name, GT_GFF_ID) && strcmp(attr_name, GT_GFF_PARENT)) {
-    if (*info->attribute_shown)
-      gt_file_xfputc(';', info->outfp);
-    else
+    if (*info->attribute_shown) {
+      if (!info->outstr)
+        gt_file_xfputc(';', info->outfp);
+      else
+        gt_str_append_char(info->outstr, ';');
+    } else
       *info->attribute_shown = true;
-    gt_file_xprintf(info->outfp, "%s=%s", attr_name, attr_value);
+    if (!info->outstr)
+      gt_file_xprintf(info->outfp, "%s=%s", attr_name, attr_value);
+    else {
+      gt_str_append_cstr(info->outstr, attr_name);
+      gt_str_append_char(info->outstr, '=');
+      gt_str_append_cstr(info->outstr, attr_value);
+    }
   }
 }
 
@@ -136,25 +164,53 @@ static int gff3_show_feature_node(GtFeatureNode *fn, void *data,
   gt_assert(fn && gff3_visitor);
 
   /* output leading part */
-  gt_gff3_output_leading(fn, gff3_visitor->outfp);
+  if (!gff3_visitor->outstr) {
+    gt_gff3_output_leading(fn, gff3_visitor->outfp);
+  } else {
+    gt_gff3_output_leading_str(fn, gff3_visitor->outstr);
+  }
 
   /* show unique id part of attributes */
   if ((id = gt_hashmap_get(gff3_visitor->feature_node_to_unique_id_str, fn))) {
-    gt_file_xprintf(gff3_visitor->outfp, "%s=%s", GT_GFF_ID, gt_str_get(id));
+    if (!gff3_visitor->outstr)
+      gt_file_xprintf(gff3_visitor->outfp, "%s=%s", GT_GFF_ID, gt_str_get(id));
+    else {
+      gt_str_append_cstr(gff3_visitor->outstr, GT_GFF_ID);
+      gt_str_append_char(gff3_visitor->outstr, '=');
+      gt_str_append_cstr(gff3_visitor->outstr, gt_str_get(id));
+    }
     part_shown = true;
   }
 
   /* show parent part of attributes */
   parent_features = gt_hashmap_get(gff3_visitor->feature_node_to_id_array, fn);
   if (gt_array_size(parent_features)) {
-    if (part_shown)
-      gt_file_xfputc(';', gff3_visitor->outfp);
-    gt_file_xprintf(gff3_visitor->outfp, "%s=", GT_GFF_PARENT);
+    if (part_shown) {
+      if (!gff3_visitor->outstr)
+        gt_file_xfputc(';', gff3_visitor->outfp);
+      else
+        gt_str_append_char(gff3_visitor->outstr, ';');
+    }
+    if (!gff3_visitor->outstr)
+      gt_file_xprintf(gff3_visitor->outfp, "%s=", GT_GFF_PARENT);
+    else {
+      gt_str_append_cstr(gff3_visitor->outstr, GT_GFF_PARENT);
+      gt_str_append_char(gff3_visitor->outstr, '=');
+    }
     for (i = 0; i < gt_array_size(parent_features); i++) {
-      if (i)
-        gt_file_xfputc(',', gff3_visitor->outfp);
-      gt_file_xprintf(gff3_visitor->outfp, "%s",
-                      *(char**) gt_array_get(parent_features, i));
+      if (i) {
+        if (!gff3_visitor->outstr)
+          gt_file_xfputc(',', gff3_visitor->outfp);
+        else
+          gt_str_append_char(gff3_visitor->outstr, ',');
+      }
+      if (!gff3_visitor->outstr) {
+        gt_file_xprintf(gff3_visitor->outfp, "%s",
+                        *(char**) gt_array_get(parent_features, i));
+      } else {
+        gt_str_append_cstr(gff3_visitor->outstr,
+                           *(char**) gt_array_get(parent_features, i));
+      }
     }
     part_shown = true;
   }
@@ -162,14 +218,22 @@ static int gff3_show_feature_node(GtFeatureNode *fn, void *data,
   /* show missing part of attributes */
   info.attribute_shown = &part_shown;
   info.outfp = gff3_visitor->outfp;
+  info.outstr = gff3_visitor->outstr;
   gt_feature_node_foreach_attribute(fn, show_attribute, &info);
 
   /* show dot if no attributes have been shown */
-  if (!part_shown)
-    gt_file_xfputc('.', gff3_visitor->outfp);
+  if (!part_shown) {
+    if (!gff3_visitor->outstr)
+      gt_file_xfputc('.', gff3_visitor->outfp);
+    else
+      gt_str_append_char(gff3_visitor->outstr, '.');
+  }
 
   /* show terminal newline */
-  gt_file_xfputc('\n', gff3_visitor->outfp);
+  if (!gff3_visitor->outstr)
+    gt_file_xfputc('\n', gff3_visitor->outfp);
+  else
+    gt_str_append_char(gff3_visitor->outstr, '\n');
 
   return 0;
 }
@@ -186,7 +250,7 @@ static GtStr* create_unique_id(GtGFF3Visitor *gff3_visitor, GtFeatureNode *fn)
 
   /* build id string */
   id = gt_str_new_cstr(type);
-  gt_str_append_ulong(id, gt_string_distri_get(gff3_visitor->id_counter, type));
+  gt_str_append_uword(id, gt_string_distri_get(gff3_visitor->id_counter, type));
 
   /* store (unique) id */
   gt_hashmap_add(gff3_visitor->feature_node_to_unique_id_str, fn, id);
@@ -198,7 +262,7 @@ static void make_unique_id_string(GtStr *current_id, GtUword counter)
 {
   /* name => name.1 */
   gt_str_append_char(current_id, '.');
-  gt_str_append_ulong(current_id, counter);
+  gt_str_append_uword(current_id, counter);
 }
 
 static bool id_string_is_unique(GtStr *id, GtStr *buf, GtCstrTable *tab,
@@ -215,16 +279,19 @@ static GtStr* make_id_unique(GtGFF3Visitor *gff3_visitor, GtFeatureNode *fn)
   GtUword i = 1;
   GtStr *id = gt_str_new_cstr(gt_feature_node_get_attribute(fn, "ID"));
 
-  if (gt_cstr_table_get(gff3_visitor->used_ids, gt_str_get(id))) {
-    GtStr *buf = gt_str_new();
-    while (!id_string_is_unique(id, buf, gff3_visitor->used_ids, i++));
-    gt_warning("feature ID \"%s\" not unique: changing to %s", gt_str_get(id),
+  if (!gff3_visitor->allow_nonunique_ids) {
+    if (gt_cstr_table_get(gff3_visitor->used_ids, gt_str_get(id))) {
+      GtStr *buf = gt_str_new();
+      while (!id_string_is_unique(id, buf, gff3_visitor->used_ids, i++));
+      gt_warning("feature ID \"%s\" not unique: changing to %s", gt_str_get(id),
                                                                gt_str_get(buf));
-    gt_str_set(id, gt_str_get(buf));
-    gt_str_delete(buf);
+      gt_str_set(id, gt_str_get(buf));
+      gt_str_delete(buf);
+    }
+    /* update table with the new id */
+    gt_cstr_table_add(gff3_visitor->used_ids, gt_str_get(id));
   }
-  /* update table with the new id */
-  gt_cstr_table_add(gff3_visitor->used_ids, gt_str_get(id));
+
   /* store (unique) id */
   gt_hashmap_add(gff3_visitor->feature_node_to_unique_id_str, fn, id);
 
@@ -314,7 +381,12 @@ static int gff3_visitor_feature_node(GtNodeVisitor *nv, GtFeatureNode *fn,
      the feature is complete, because no ID attribute has been shown) */
   if (gt_feature_node_has_children(fn) ||
       (gff3_visitor->retain_ids && gt_feature_node_get_attribute(fn, "ID"))) {
-    gt_file_xprintf(gff3_visitor->outfp, "%s\n", GT_GFF_TERMINATOR);
+    if (!gff3_visitor->outstr)
+      gt_file_xprintf(gff3_visitor->outfp, "%s\n", GT_GFF_TERMINATOR);
+    else {
+      gt_str_append_cstr(gff3_visitor->outstr, GT_GFF_TERMINATOR);
+      gt_str_append_char(gff3_visitor->outstr, '\n');
+    }
   }
 
   return had_err;
@@ -324,6 +396,7 @@ static int gff3_visitor_meta_node(GtNodeVisitor *nv, GtMetaNode *mn,
                                   GT_UNUSED GtError *err)
 {
   GtGFF3Visitor *gff3_visitor;
+  const char *data;
   gt_error_check(err);
   gff3_visitor = gff3_visitor_cast(nv);
   gt_assert(nv && mn);
@@ -337,9 +410,24 @@ static int gff3_visitor_meta_node(GtNodeVisitor *nv, GtMetaNode *mn,
       gff3_version_string(nv);
     }
   }
-  gt_file_xprintf(gff3_visitor->outfp, "##%s %s\n",
-                  gt_meta_node_get_directive(mn),
-                  gt_meta_node_get_data(mn));
+  data = gt_meta_node_get_data(mn);
+  if (!gff3_visitor->outstr) {
+    if (data) {
+      gt_file_xprintf(gff3_visitor->outfp, "##%s %s\n",
+                      gt_meta_node_get_directive(mn), data);
+    } else {
+      gt_file_xprintf(gff3_visitor->outfp, "##%s\n",
+                      gt_meta_node_get_directive(mn));
+    }
+  } else {
+    gt_str_append_cstr(gff3_visitor->outstr, "##");
+    gt_str_append_cstr(gff3_visitor->outstr, gt_meta_node_get_directive(mn));
+    if (data) {
+      gt_str_append_char(gff3_visitor->outstr, ' ');
+      gt_str_append_cstr(gff3_visitor->outstr, data);
+    }
+    gt_str_append_char(gff3_visitor->outstr, '\n');
+  }
   return 0;
 }
 
@@ -351,11 +439,25 @@ static int gff3_visitor_region_node(GtNodeVisitor *nv, GtRegionNode *rn,
   gff3_visitor = gff3_visitor_cast(nv);
   gt_assert(nv && rn);
   gff3_version_string(nv);
-  gt_file_xprintf(gff3_visitor->outfp, "%s   %s "GT_WU" "GT_WU"\n",
-                  GT_GFF_SEQUENCE_REGION,
-                  gt_str_get(gt_genome_node_get_seqid((GtGenomeNode*) rn)),
-                  gt_genome_node_get_start((GtGenomeNode*) rn),
-                  gt_genome_node_get_end((GtGenomeNode*) rn));
+  if (!gff3_visitor->outstr) {
+    gt_file_xprintf(gff3_visitor->outfp, "%s   %s "GT_WU" "GT_WU"\n",
+                    GT_GFF_SEQUENCE_REGION,
+                    gt_str_get(gt_genome_node_get_seqid((GtGenomeNode*) rn)),
+                    gt_genome_node_get_start((GtGenomeNode*) rn),
+                    gt_genome_node_get_end((GtGenomeNode*) rn));
+  } else {
+    gt_str_append_cstr(gff3_visitor->outstr, GT_GFF_SEQUENCE_REGION);
+    gt_str_append_cstr(gff3_visitor->outstr, "   ");
+    gt_str_append_cstr(gff3_visitor->outstr,
+                      gt_str_get(gt_genome_node_get_seqid((GtGenomeNode*) rn)));
+    gt_str_append_char(gff3_visitor->outstr, ' ');
+    gt_str_append_uword(gff3_visitor->outstr,
+                                  gt_genome_node_get_start((GtGenomeNode*) rn));
+    gt_str_append_char(gff3_visitor->outstr, ' ');
+    gt_str_append_uword(gff3_visitor->outstr,
+                                  gt_genome_node_get_end((GtGenomeNode*) rn));
+    gt_str_append_char(gff3_visitor->outstr, '\n');
+  }
   return 0;
 }
 
@@ -368,13 +470,25 @@ static int gff3_visitor_sequence_node(GtNodeVisitor *nv, GtSequenceNode *sn,
   gt_assert(nv && sn);
   gff3_version_string(nv);
   if (!gff3_visitor->fasta_directive_shown) {
-    gt_file_xprintf(gff3_visitor->outfp, "%s\n", GT_GFF_FASTA_DIRECTIVE);
+    if (!gff3_visitor->outstr)
+      gt_file_xprintf(gff3_visitor->outfp, "%s\n", GT_GFF_FASTA_DIRECTIVE);
+    else {
+      gt_str_append_cstr(gff3_visitor->outstr, GT_GFF_FASTA_DIRECTIVE);
+      gt_str_append_char(gff3_visitor->outstr, '\n');
+    }
     gff3_visitor->fasta_directive_shown = true;
   }
-  gt_fasta_show_entry(gt_sequence_node_get_description(sn),
-                      gt_sequence_node_get_sequence(sn),
-                      gt_sequence_node_get_sequence_length(sn),
-                      gff3_visitor->fasta_width, gff3_visitor->outfp);
+  if (!gff3_visitor->outstr) {
+    gt_fasta_show_entry(gt_sequence_node_get_description(sn),
+                        gt_sequence_node_get_sequence(sn),
+                        gt_sequence_node_get_sequence_length(sn),
+                        gff3_visitor->fasta_width, gff3_visitor->outfp);
+  } else {
+    gt_fasta_show_entry_str(gt_sequence_node_get_description(sn),
+                            gt_sequence_node_get_sequence(sn),
+                            gt_sequence_node_get_sequence_length(sn),
+                            gff3_visitor->fasta_width, gff3_visitor->outstr);
+  }
   return 0;
 }
 
@@ -403,10 +517,8 @@ const GtNodeVisitorClass* gt_gff3_visitor_class()
   return nvc;
 }
 
-GtNodeVisitor* gt_gff3_visitor_new(GtFile *outfp)
+static void gt_gff3_visitor_init(GtGFF3Visitor *gff3_visitor)
 {
-  GtNodeVisitor *nv = gt_node_visitor_create(gt_gff3_visitor_class());
-  GtGFF3Visitor *gff3_visitor = gff3_visitor_cast(nv);
   gff3_visitor->version_string_shown = false;
   gff3_visitor->fasta_directive_shown = false;
   gff3_visitor->id_counter = gt_string_distri_new();
@@ -415,10 +527,29 @@ GtNodeVisitor* gt_gff3_visitor_new(GtFile *outfp)
   gff3_visitor->feature_node_to_unique_id_str =
     gt_hashmap_new(GT_HASH_DIRECT, NULL, (GtFree) gt_str_delete);
   gff3_visitor->fasta_width = 0;
-  gff3_visitor->outfp = outfp;
   gff3_visitor->used_ids = gt_cstr_table_new();
   /* XXX */
   gff3_visitor->retain_ids = getenv("GT_RETAINIDS") ? true : false;
+  gff3_visitor->allow_nonunique_ids = false;
+}
+
+GtNodeVisitor* gt_gff3_visitor_new(GtFile *outfp)
+{
+  GtNodeVisitor *nv = gt_node_visitor_create(gt_gff3_visitor_class());
+  GtGFF3Visitor *gff3_visitor = gff3_visitor_cast(nv);
+  gt_gff3_visitor_init(gff3_visitor);
+  gff3_visitor->outfp = gt_file_ref(outfp);
+  gff3_visitor->outstr = NULL;
+  return nv;
+}
+
+GtNodeVisitor* gt_gff3_visitor_new_to_str(GtStr *outstr)
+{
+  GtNodeVisitor *nv = gt_node_visitor_create(gt_gff3_visitor_class());
+  GtGFF3Visitor *gff3_visitor = gff3_visitor_cast(nv);
+  gt_gff3_visitor_init(gff3_visitor);
+  gff3_visitor->outfp = NULL;
+  gff3_visitor->outstr = gt_str_ref(outstr);
   return nv;
 }
 
@@ -428,6 +559,12 @@ void gt_gff3_visitor_retain_id_attributes(GtGFF3Visitor *gff3_visitor)
   gff3_visitor->retain_ids = true;
 }
 
+void gt_gff3_visitor_allow_nonunique_ids(GtGFF3Visitor *gff3_visitor)
+{
+  gt_assert(gff3_visitor);
+  gff3_visitor->allow_nonunique_ids = true;
+}
+
 void gt_gff3_visitor_set_fasta_width(GtGFF3Visitor *gff3_visitor,
                                      GtUword fasta_width)
 {
