@@ -52,6 +52,7 @@
 #include "core/symbol.h"
 #include "core/tokenizer.h"
 #include "core/translator.h"
+#include "core/trans_table.h"
 #include "extended/alignment.h"
 #include "extended/anno_db_gfflike_api.h"
 #include "extended/compressed_bitsequence.h"
@@ -118,6 +119,8 @@
 #include "tools/gt_gtf_to_gff3.h"
 #include "tools/gt_hop.h"
 #include "tools/gt_id_to_md5.h"
+#include "tools/gt_inlineseq_split.h"
+#include "tools/gt_inlineseq_add.h"
 #include "tools/gt_interfeat.h"
 #include "tools/gt_loccheck.h"
 #include "tools/gt_matchtool.h"
@@ -212,6 +215,8 @@ GtToolbox* gtt_tools(void)
   gt_toolbox_add_tool(tools, "gtf_to_gff3", gt_gtf_to_gff3());
   gt_toolbox_add_tool(tools, "hop", gt_hop());
   gt_toolbox_add_tool(tools, "id_to_md5", gt_id_to_md5());
+  gt_toolbox_add_tool(tools, "inlineseq_split", gt_inlineseq_split());
+  gt_toolbox_add_tool(tools, "inlineseq_add", gt_inlineseq_add());
   gt_toolbox_add_tool(tools, "interfeat", gt_interfeat());
   gt_toolbox_add_tool(tools, "loccheck", gt_loccheck());
   gt_toolbox_add_tool(tools, "ltrclustering", gt_ltrclustering());
@@ -362,6 +367,7 @@ GtHashmap* gtt_unit_tests(void)
   gt_hashmap_add(unit_tests, "tag value map example", gt_tag_value_map_example);
   gt_hashmap_add(unit_tests, "tokenizer class", gt_tokenizer_unit_test);
   gt_hashmap_add(unit_tests, "translator class", gt_translator_unit_test);
+  gt_hashmap_add(unit_tests, "transtable class", gt_trans_table_unit_test);
   gt_hashmap_add(unit_tests, "uint64hashtable", gt_uint64hashtable_unit_test);
   gt_hashmap_add(unit_tests, "xdrop", gt_xdrop_unit_test);
 #ifndef WITHOUT_CAIRO
