@@ -15,11 +15,11 @@
   OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */
 
-#ifndef S_SPLINT_S
 #include <ctype.h>
-#endif
 #include <string.h>
+
 #include "core/bioseq.h"
+#include "core/encseq.h"
 #include "core/fileutils_api.h"
 #include "core/log.h"
 #include "core/logger.h"
@@ -36,14 +36,14 @@
 #include "extended/seqid2file.h"
 #include "extended/visitor_stream.h"
 #include "ltr/gt_ltrdigest.h"
+#include "ltr/ltr_input_check_visitor.h"
 #include "ltr/ltrdigest_def.h"
+#include "ltr/ltrdigest_file_out_stream.h"
 #include "ltr/ltrdigest_pbs_visitor.h"
 #include "ltr/ltrdigest_pdom_visitor.h"
 #include "ltr/ltrdigest_ppt_visitor.h"
 #include "ltr/ltrdigest_strand_assign_visitor.h"
-#include "ltr/ltrdigest_file_out_stream.h"
 #include "ltr/pdom_model_set.h"
-#include "core/encseq.h"
 
 typedef struct GtLTRdigestOptions {
   GtStr *trna_lib, *prefix, *cutoffs;
@@ -51,7 +51,8 @@ typedef struct GtLTRdigestOptions {
        write_alignments,
        write_aaseqs,
        output_all_chains,
-       print_metadata;
+       print_metadata,
+       force_recreate;
   GtOutputFileInfo *ofi;
   GtFile *outfp;
   GtStrArray *hmm_files;
@@ -347,6 +348,12 @@ static GtOptionParser* gt_ltrdigest_option_parser_new(void *tool_arguments)
   gt_option_parser_add_option(op, o);
   gt_option_is_development_option(o);
 
+  o = gt_option_new_bool("force_recreate",
+                         "force recreation of hmmpressed profiles",
+                         &arguments->force_recreate,
+                         false);
+  gt_option_parser_add_option(op, o);
+
   /* Extended PBS options */
 
   o = gt_option_new_int("pbsmatchscore",
@@ -428,6 +435,7 @@ static int gt_ltrdigest_runner(GT_UNUSED int argc, const char **argv,
 {
   GtLTRdigestOptions *arguments = tool_arguments;
   GtNodeStream *gff3_in_stream  = NULL,
+               *check_stream    = NULL,
                *gff3_out_stream = NULL,
                *pdom_stream     = NULL,
                *ppt_stream      = NULL,
@@ -512,9 +520,16 @@ static int gt_ltrdigest_runner(GT_UNUSED int argc, const char **argv,
     last_stream = gff3_in_stream  = gt_gff3_in_stream_new_sorted(argv[arg]);
   }
 
+  if (!had_err) {
+    GtNodeVisitor *check_v;
+    check_v = gt_ltr_input_check_visitor_new();
+    last_stream = check_stream = gt_visitor_stream_new(last_stream, check_v);
+  }
+
   if (!had_err && gt_str_array_size(arguments->hmm_files) > 0) {
     GtNodeVisitor *pdom_v;
-    ms = gt_pdom_model_set_new(arguments->hmm_files, err);
+    ms = gt_pdom_model_set_new(arguments->hmm_files, arguments->force_recreate,
+                               err);
     if (ms != NULL) {
       pdom_v = gt_ltrdigest_pdom_visitor_new(ms, arguments->evalue_cutoff,
                                              arguments->chain_max_gap_length,
@@ -637,6 +652,7 @@ static int gt_ltrdigest_runner(GT_UNUSED int argc, const char **argv,
   gt_node_stream_delete(sa_stream);
   gt_node_stream_delete(pdom_stream);
   gt_node_stream_delete(tab_out_stream);
+  gt_node_stream_delete(check_stream);
   gt_node_stream_delete(gff3_in_stream);
   gt_bioseq_delete(arguments->trna_lib_bs);
   gt_region_mapping_delete(rmap);
