@@ -1,6 +1,7 @@
 /*
-  Copyright (c) 2013 Sascha Steinbiss <steinbiss@zbh.uni-hamburg.de>
-  Copyright (c) 2013 Center for Bioinformatics, University of Hamburg
+  Copyright (c) 2013-2014 Sascha Steinbiss <ss34@sanger.ac.uk>
+  Copyright (c) 2013      Center for Bioinformatics, University of Hamburg
+  Copyright (c)      2014 Genome Research Ltd.
 
   Permission to use, copy, modify, and distribute this software for any
   purpose with or without fee is hereby granted, provided that the above
@@ -15,22 +16,22 @@
   OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */
 
+#include <ctype.h>
 #include <signal.h>
 #include <string.h>
-#ifndef S_SPLINT_S
-#include <ctype.h>
 #include <sys/types.h>
 #include <unistd.h>
 #ifndef _WIN32
 #include <sys/wait.h>
 #endif
-#endif
+
 #include "core/array_api.h"
 #include "core/codon_api.h"
 #include "core/codon_iterator_api.h"
 #include "core/codon_iterator_simple_api.h"
 #include "core/cstr_api.h"
 #include "core/cstr_array.h"
+#include "core/grep_api.h"
 #include "core/hashmap.h"
 #include "core/log.h"
 #include "core/ma.h"
@@ -43,12 +44,14 @@
 #include "core/translator_api.h"
 #include "core/undef_api.h"
 #include "core/unused_api.h"
+#include "core/warning_api.h"
 #include "extended/node_visitor_api.h"
 #include "extended/extract_feature_sequence.h"
 #include "extended/feature_node.h"
 #include "extended/feature_node_iterator_api.h"
 #include "extended/feature_type.h"
 #include "extended/globalchaining.h"
+#include "extended/node_visitor_api.h"
 #include "extended/reverse_api.h"
 #include "ltr/ltrdigest_def.h"
 #include "ltr/ltrdigest_pdom_visitor.h"
@@ -328,7 +331,6 @@ static int gt_ltrdigest_pdom_visitor_parse_alignments(GT_UNUSED
                                                      GtError *err)
 {
   int had_err = 0, cur_domain = GT_UNDEF_INT, line = GT_UNDEF_INT;
-  bool first_align_line = false;
   int mod_val = 4;
   GtHMMERSingleHit *hit = NULL;
   gt_assert(lv && instream && status);
@@ -347,36 +349,29 @@ static int gt_ltrdigest_pdom_visitor_parse_alignments(GT_UNUSED
       gt_assert(hit && !hit->alignment);
       hit->alignment = gt_str_new();
       hit->aastring = gt_str_new();
-      first_align_line = true;
-      mod_val = 4;
+      mod_val = 3;
+      line = 0;
     } else {
-      bool run = true;
-      char junkbuf[BUFSIZ];
-      if (first_align_line) {
-        /* some models contain consensus structure annotation -- in this case
-           there is an additional line in the output which must be taken
-           into account */
-        line = 0;
-        if (1 == sscanf(buf, "%*s %s", junkbuf)) {
-          if (0 == strcmp(junkbuf, "CS")) {
-            mod_val = 5;
-            line = -1;
-            run = false;
-          }
-        }
-        first_align_line = false;
-      }
-      if (run) {
+      bool junk_match = false;
+      (void) gt_grep(&junk_match, " (CS|RF|PP)$", buf, NULL);
+      if (line % mod_val == 1 || !junk_match) {
         gt_assert(hit && hit->alignment);
-        gt_str_append_cstr(hit->alignment, buf);
-        gt_str_append_char(hit->alignment, '\n');
         switch (line % mod_val) {
+          case 0:
+            if (line > 0)
+              gt_str_append_char(hit->alignment, '\n');
+            gt_str_append_cstr(hit->alignment, buf);
+            gt_str_append_char(hit->alignment, '\n');
+            break;
           case 1:
+            gt_str_append_cstr(hit->alignment, buf);
             gt_str_append_char(hit->alignment, '\n');
             break;
           case 2:
             {
               GT_UNUSED char *b = buf;
+              gt_str_append_cstr(hit->alignment, buf);
+              gt_str_append_char(hit->alignment, '\n');
               b = strtok(buf, " ");
               gt_assert(strspn(b, "012+-") == (size_t) 2);
               b = strtok(NULL, " ");
@@ -386,8 +381,8 @@ static int gt_ltrdigest_pdom_visitor_parse_alignments(GT_UNUSED
             }
             break;
         }
+        line++;
       }
-      line++;
     }
     had_err = pdom_parser_get_next_line(buf, instream, err);
   }
@@ -618,7 +613,7 @@ static int gt_ltrdigest_pdom_visitor_attach_hit(GtLTRdigestPdomVisitor *lv,
       for (j = 0UL; j < gt_array_size(singlehit->chains); j++) {
         gt_str_append_cstr(buffer, modelhit->modelname);
         gt_str_append_char(buffer, ':');
-        gt_str_append_ulong(buffer,
+        gt_str_append_uword(buffer,
                           *(GtUword*) gt_array_get(singlehit->chains, j));
         if (j != gt_array_size(singlehit->chains) - 1) {
           gt_str_append_char(buffer, ',');
@@ -822,102 +817,111 @@ static int gt_ltrdigest_pdom_visitor_feature_node(GtNodeVisitor *nv,
                                           lv->root_type,
                                           false, NULL, NULL, lv->rmap, err);
 
-    if (!had_err) {
-      for (i = 0UL; i < 3UL; i++) {
-        gt_str_reset(lv->fwd[i]);
-        gt_str_reset(lv->rev[i]);
-      }
-
-      /* create translations */
-      ci = gt_codon_iterator_simple_new(gt_str_get(seq), seqlen, NULL);
-      gt_assert(ci);
-      tr = gt_translator_new(ci);
-      status = gt_translator_next(tr, &translated, &frame, err);
-      while (status == GT_TRANSLATOR_OK && translated) {
-        gt_str_append_char(lv->fwd[frame], translated);
-        status = gt_translator_next(tr, &translated, &frame, NULL);
-      }
-      if (status == GT_TRANSLATOR_ERROR) had_err = -1;
+    if (!had_err && gt_str_length(seq) >= (GtUword) (3*GT_CODON_LENGTH)) {
       if (!had_err) {
-        rev_seq = gt_malloc((size_t) seqlen * sizeof (char));
-        strncpy(rev_seq, gt_str_get(seq), (size_t) seqlen * sizeof (char));
-        (void) gt_reverse_complement(rev_seq, seqlen, NULL);
-        gt_codon_iterator_delete(ci);
-        ci = gt_codon_iterator_simple_new(rev_seq, seqlen, NULL);
-        gt_translator_set_codon_iterator(tr, ci);
+        for (i = 0UL; i < 3UL; i++) {
+          gt_str_reset(lv->fwd[i]);
+          gt_str_reset(lv->rev[i]);
+        }
+
+        /* create translations */
+        ci = gt_codon_iterator_simple_new(gt_str_get(seq), seqlen, NULL);
+        gt_assert(ci);
+        tr = gt_translator_new(ci);
         status = gt_translator_next(tr, &translated, &frame, err);
         while (status == GT_TRANSLATOR_OK && translated) {
-          gt_str_append_char(lv->rev[frame], translated);
+          gt_str_append_char(lv->fwd[frame], translated);
           status = gt_translator_next(tr, &translated, &frame, NULL);
         }
         if (status == GT_TRANSLATOR_ERROR) had_err = -1;
-        gt_free(rev_seq);
-      }
-      gt_codon_iterator_delete(ci);
-      gt_translator_delete(tr);
-    }
-
-    /* run HMMER and handle results */
-    if (!had_err) {
-#ifndef _WIN32
-      int pid, pc[2], cp[2];
-      GT_UNUSED int rval;
-
-      (void) signal(SIGCHLD, SIG_IGN); /* XXX: for now, ignore child's
-                                               exit status */
-      rval = pipe(pc);
-      gt_assert(rval == 0);
-      rval = pipe(cp);
-      gt_assert(rval == 0);
-
-      switch ((pid = (int) fork())) {
-        case -1:
-          perror("Can't fork");
-          exit(1);   /* XXX: error handling */
-        case 0:    /* child */
-          (void) close(1);    /* close current stdout. */
-          rval = dup(cp[1]);  /* make stdout go to write end of pipe. */
-          (void) close(0);    /* close current stdin. */
-          rval = dup(pc[0]);  /* make stdin come from read end of pipe. */
-          (void) close(pc[0]);
-          (void) close(pc[1]);
-          (void) close(cp[0]);
-          (void) close(cp[1]);
-          (void) execvp("hmmscan", lv->args); /* XXX: read path from env */
-          perror("couldn't execute hmmscan!");
-          exit(1);
-        default:    /* parent */
-          for (i = 0UL; i < 3UL; i++) {
-            char buf[5];
-            GT_UNUSED ssize_t written;
-            (void) sprintf(buf, ">"GT_WU"%c\n", i, '+');
-            written = write(pc[1], buf, 4 * sizeof (char));
-            written = write(pc[1], gt_str_get(lv->fwd[i]),
-                            (size_t) gt_str_length(lv->fwd[i]) * sizeof (char));
-            written = write(pc[1], "\n", 1 * sizeof (char));
-            (void) sprintf(buf, ">"GT_WU"%c\n", i, '-');
-            written = write(pc[1], buf, 4 * sizeof (char));
-            written = write(pc[1], gt_str_get(lv->rev[i]),
-                            (size_t) gt_str_length(lv->rev[i]) * sizeof (char));
-            written = write(pc[1], "\n", 1 * sizeof (char));
+        if (!had_err) {
+          rev_seq = gt_malloc((size_t) seqlen * sizeof (char));
+          strncpy(rev_seq, gt_str_get(seq), (size_t) seqlen * sizeof (char));
+          (void) gt_reverse_complement(rev_seq, seqlen, NULL);
+          gt_codon_iterator_delete(ci);
+          ci = gt_codon_iterator_simple_new(rev_seq, seqlen, NULL);
+          gt_translator_set_codon_iterator(tr, ci);
+          status = gt_translator_next(tr, &translated, &frame, err);
+          while (status == GT_TRANSLATOR_OK && translated) {
+            gt_str_append_char(lv->rev[frame], translated);
+            status = gt_translator_next(tr, &translated, &frame, NULL);
           }
-          (void) close(pc[0]);
-          (void) close(pc[1]);
-          (void) close(cp[1]);
-          instream = fdopen(cp[0], "r");
-          pstatus = gt_hmmer_parse_status_new();
-          had_err = gt_ltrdigest_pdom_visitor_parse_output(lv, pstatus,
-                                                           instream, err);
-          (void) fclose(instream);
-          if (!had_err)
-            had_err = gt_ltrdigest_pdom_visitor_process_hits(lv, pstatus, err);
-          gt_hmmer_parse_status_delete(pstatus);
+          if (status == GT_TRANSLATOR_ERROR) had_err = -1;
+          gt_free(rev_seq);
+        }
+        gt_codon_iterator_delete(ci);
+        gt_translator_delete(tr);
       }
-#else
-      /* XXX */
-      gt_error_set(err, "HMMER call not implemented on Windows\n");
-      had_err = -1;
-#endif
+
+      /* run HMMER and handle results */
+      if (!had_err) {
+  #ifndef _WIN32
+        int pid, pc[2], cp[2];
+        GT_UNUSED int rval;
+
+        (void) signal(SIGCHLD, SIG_IGN); /* XXX: for now, ignore child's
+                                                 exit status */
+        rval = pipe(pc);
+        gt_assert(rval == 0);
+        rval = pipe(cp);
+        gt_assert(rval == 0);
+
+        switch ((pid = (int) fork())) {
+          case -1:
+            perror("Can't fork");
+            exit(1);   /* XXX: error handling */
+          case 0:    /* child */
+            (void) close(1);    /* close current stdout. */
+            rval = dup(cp[1]);  /* make stdout go to write end of pipe. */
+            (void) close(0);    /* close current stdin. */
+            rval = dup(pc[0]);  /* make stdin come from read end of pipe. */
+            (void) close(pc[0]);
+            (void) close(pc[1]);
+            (void) close(cp[0]);
+            (void) close(cp[1]);
+            (void) execvp("hmmscan", lv->args); /* XXX: read path from env */
+            perror("couldn't execute hmmscan!");
+            exit(1);
+          default:    /* parent */
+            for (i = 0UL; i < 3UL; i++) {
+              char buf[5];
+              GT_UNUSED ssize_t written;
+              (void) sprintf(buf, ">"GT_WU"%c\n", i, '+');
+              written = write(pc[1], buf, 4 * sizeof (char));
+              written = write(pc[1], gt_str_get(lv->fwd[i]),
+                            (size_t) gt_str_length(lv->fwd[i]) * sizeof (char));
+              written = write(pc[1], "\n", 1 * sizeof (char));
+              (void) sprintf(buf, ">"GT_WU"%c\n", i, '-');
+              written = write(pc[1], buf, 4 * sizeof (char));
+              written = write(pc[1], gt_str_get(lv->rev[i]),
+                            (size_t) gt_str_length(lv->rev[i]) * sizeof (char));
+              written = write(pc[1], "\n", 1 * sizeof (char));
+            }
+            (void) close(pc[0]);
+            (void) close(pc[1]);
+            (void) close(cp[1]);
+            instream = fdopen(cp[0], "r");
+            pstatus = gt_hmmer_parse_status_new();
+            had_err = gt_ltrdigest_pdom_visitor_parse_output(lv, pstatus,
+                                                             instream, err);
+            (void) fclose(instream);
+            if (!had_err)
+              had_err = gt_ltrdigest_pdom_visitor_process_hits(lv, pstatus,
+                                                               err);
+            gt_hmmer_parse_status_delete(pstatus);
+        }
+  #else
+        /* XXX */
+        gt_error_set(err, "HMMER call not implemented on Windows\n");
+        had_err = -1;
+  #endif
+      }
+    } else {
+      gt_warning("LTR_retrotransposon (%s, line %u) is too short to be "
+                 "translated (" GT_WU " nt), skipped domain search",
+            gt_genome_node_get_filename((GtGenomeNode*) lv->ltr_retrotrans),
+            gt_genome_node_get_line_number((GtGenomeNode*) lv->ltr_retrotrans),
+            gt_str_length(seq));
     }
     gt_str_delete(seq);
   }
