@@ -22,6 +22,7 @@
 #include "core/assert_api.h"
 #include "core/log_api.h"
 #include "core/mathsupport.h"
+#include "core/unused_api.h"
 #include "match/shu-divergence.h"
 
 static double pmax(double M, /* M value should be explored by simulation ??? */
@@ -31,20 +32,15 @@ static double pmax(double M, /* M value should be explored by simulation ??? */
             int *thresholdReached,
             double *ln_n_fac,
             double *s1,
-            GtUword n_s)
+            GT_UNUSED GtUword n_s)
 {
 
   GtUword k;
   double s = 0.0, ln_x_choose_k;
   double ln, ln1, m1, m, delta;
 
-  if (x > n_s) {
-    /* change this to standard GT-behaviour XXX*/
-    printf("Error: x = "GT_WU"."
-           " The maximum number of elements in the array"
-           " s1 should be increased!\n", x);
-  }
-  gt_assert(x <= n_s);
+  gt_assert(x <= n_s || " The maximum number of elements in the array s1 "
+            "should be increased!");
   if (s1[x] != 0.0)
     return s1[x];
 
