@@ -201,9 +201,8 @@ end
 Name "gt gff3 test 17"
 Keywords "gt_gff3"
 Test do
-  run_test "#{$bin}gt gff3 #{$testdata}gt_gff3_test_17.gff3", :retval => 1
+  run_test "#{$bin}gt gff3 #{$testdata}gt_gff3_test_17.gff3"
   grep(last_stderr, /unknown meta-directive encountered/);
-  grep(last_stderr, /does not have data: ##foo/);
 end
 
 Name "gt gff3 test 18"
@@ -233,6 +232,13 @@ Test do
   grep(last_stderr, /does not equal required version/);
 end
 
+Name "gt gff3 test 21 (-tidy)"
+Keywords "gt_gff3"
+Test do
+  run_test("#{$bin}gt gff3 -tidy #{$testdata}gt_gff3_test_21.gff3")
+  grep(last_stderr, /try to parse as version 3/);
+end
+
 Name "gt gff3 test 22"
 Keywords "gt_gff3"
 Test do
@@ -1281,6 +1287,16 @@ Test do
   run "diff #{last_stdout} #{$testdata}unknown_meta_directive.gff3"
 end
 
+Name "gt gff3 unknown meta directive (without argument)"
+Keywords "gt_gff3"
+Test do
+  run_test "#{$bin}gt gff3 " +
+           "#{$testdata}unknown_meta_directive_without_argument.gff3"
+  grep last_stderr, "unknown meta-directive encountered in line"
+  run "diff #{last_stdout} " +
+      "#{$testdata}unknown_meta_directive_without_argument.gff3"
+end
+
 Name "gt gff3 simple cycle"
 Keywords "gt_gff3"
 Test do
@@ -1302,6 +1318,20 @@ Test do
   grep last_stderr, "was not defined"
 end
 
+Name "gt gff3 multi-feature orphan (success)"
+Keywords "gt_gff3"
+Test do
+  run_test "#{$bin}gt gff3 #{$testdata}multi_feature_orphan_succ.gff3"
+end
+
+Name "gt gff3 multi-feature orphan (failure)"
+Keywords "gt_gff3"
+Test do
+  run_test "#{$bin}gt gff3 #{$testdata}multi_feature_orphan_fail.gff3",
+           :retval => 1
+  grep last_stderr, "does not have a 'Parent' attribute which is present"
+end
+
 Name "gt gff3 uppercase attributes"
 Keywords "gt_gff3"
 Test do
@@ -1397,6 +1427,82 @@ Test do
   grep last_stderr, "ends with a blank, removing"
 end
 
+Name "gt gff3 -sortlines (missing -sort) "
+Keywords "gt_gff3 linesorting"
+Test do
+  run_test "#{$bin}gt gff3 -sortlines #{$testdata}eden.gff3", :retval => 1
+  grep last_stderr, "requires option \"-sort\""
+end
+
+Name "gt gff3 -sortlines (standard gene)"
+Keywords "gt_gff3 linesorting"
+Test do
+  run "#{$bin}gt #{$testdata}/gtscripts/check_linesorting.lua #{$testdata}eden.gff3", :retval => 1
+  run_test "#{$bin}gt gff3 -sort #{$testdata}eden.gff3"
+  run "#{$bin}gt #{$testdata}/gtscripts/check_linesorting.lua #{last_stdout}", :retval => 1
+  run_test "#{$bin}gt gff3 -sort -retainids -sortlines #{$testdata}eden.gff3"
+end
+
+Name "gt gff3 -sortlines (three non-overlapping genes)"
+Keywords "gt_gff3 linesorting"
+Test do
+  run "#{$bin}gt #{$testdata}/gtscripts/check_linesorting.lua #{$testdata}gt_gff3_linesort.in.gff3", :retval => 1
+  run_test "#{$bin}gt gff3 -sort -retainids #{$testdata}gt_gff3_linesort.in.gff3 > 1"
+  run "#{$bin}gt #{$testdata}/gtscripts/check_linesorting.lua 1", :retval => 1
+  run_test "#{$bin}gt gff3 -sort -retainids -sortlines #{$testdata}gt_gff3_linesort.in.gff3 > 2"
+  run "#{$bin}gt #{$testdata}/gtscripts/check_linesorting.lua 2"
+  run_test "#{$bin}gt gff3 -sort -retainids 2 > 3"
+  run "diff 1 3"
+end
+
+Name "gt gff3 -sortlines (three partially overlapping genes)"
+Keywords "gt_gff3 linesorting"
+Test do
+  run "#{$bin}gt #{$testdata}/gtscripts/check_linesorting.lua #{$testdata}gt_gff3_linesort2.in.gff3", :retval => 1
+  run_test "#{$bin}gt gff3 -sort -retainids #{$testdata}gt_gff3_linesort2.in.gff3 > 1"
+  run "#{$bin}gt #{$testdata}/gtscripts/check_linesorting.lua 1", :retval => 1
+  run_test "#{$bin}gt gff3 -sort -retainids -sortlines #{$testdata}gt_gff3_linesort2.in.gff3 > 2"
+  run "#{$bin}gt #{$testdata}/gtscripts/check_linesorting.lua 2"
+  run_test "#{$bin}gt gff3 -sort -retainids 2 > 3"
+  run "diff 1 3"
+end
+
+Name "gt gff3 -sortlines (multiple sequences)"
+Keywords "gt_gff3 linesorting"
+Test do
+  run "#{$bin}gt #{$testdata}/gtscripts/check_linesorting.lua #{$testdata}encode_known_genes_Mar07.gff3", :retval => 1
+  run_test "#{$bin}gt gff3 -sort -retainids #{$testdata}encode_known_genes_Mar07.gff3 > 1"
+  run "#{$bin}gt #{$testdata}/gtscripts/check_linesorting.lua 1", :retval => 1
+  run_test "#{$bin}gt gff3 -sort -retainids -sortlines #{$testdata}encode_known_genes_Mar07.gff3 > 2"
+  run "#{$bin}gt #{$testdata}/gtscripts/check_linesorting.lua 2"
+end
+
+Name "gt gff3 -sortlines (empty annotation)"
+Keywords "gt_gff3 linesorting"
+Test do
+  run_test "#{$bin}gt gff3 -sort -retainids #{$testdata}empty.gff3 > 1"
+  run_test "#{$bin}gt gff3 -sort -retainids -sortlines #{$testdata}empty.gff3 > 2"
+  run "diff 1 2"
+end
+
+Name "gt gff3 -sortlines (annotation with sequence)"
+Keywords "gt_gff3 linesorting"
+Test do
+  run "#{$bin}gt #{$testdata}/gtscripts/check_linesorting.lua #{$testdata}/standard_fasta_example.gff3", :retval => 1
+  run_test "#{$bin}gt gff3 -sort -retainids #{$testdata}standard_fasta_example.gff3 > 1"
+  run "#{$bin}gt #{$testdata}/gtscripts/check_linesorting.lua 1", :retval => 1
+  run_test "#{$bin}gt gff3 -sort -retainids -sortlines #{$testdata}standard_fasta_example.gff3 > 2"
+  run "#{$bin}gt #{$testdata}/gtscripts/check_linesorting.lua 2"
+  run_test "#{$bin}gt gff3 -sort -retainids 2 > 3"
+  run "diff 1 3"
+end
+
+Name "gt gff3 (double free regression)"
+Keywords "gt_gff3"
+Test do
+  run "#{$bin}gt gff3 #{$testdata}/double_free.gff3", :retval => 1
+end
+
 def large_gff3_test(name, file)
   Name "gt gff3 #{name}"
   Keywords "gt_gff3 large_gff3"
